
# Type: uri


a complete URI

URI: [https://example.com/test62/meta:types/Uri](https://example.com/test62/meta:types/Uri)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **URI** |
| Representation | | str |
